<template>
  <div class="login-container">
    <div class="login-card-wrapper">
      <div class="login-card">
        <!-- Header Section -->
        <div class="card-header">
          <div class="header-icon">
            <svg class="icon" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" 
                d="M15 7a2 2 0 012 2m4 0a6 6 0 01-7.743 5.743L11 17H9v2H7v2H4a1 1 0 01-1-1v-2.586a1 1 0 01.293-.707l5.964-5.964A6 6 0 1121 9z" />
            </svg>
          </div>
          <h2>Welcome Back</h2>
          <p>Please sign in to continue</p>
        </div>

        <!-- Content Section -->
        <div class="card-content">
          <form @submit.prevent="login">
            <div class="form-group">
              <input
                v-model="email"
                id="email"
                type="email"
                placeholder="Email"
                required
                :disabled="isSubmitting"
              />
            </div>
            <div class="form-group">
              <input
                v-model="password"
                id="password"
                type="password"
                placeholder="Password"
                required
                :disabled="isSubmitting"
              />
            </div>

            <!-- Error Messages -->
            <div v-if="errors.email || errors.password" class="error-container">
              <div class="error-icon">
                <svg class="icon" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" 
                    d="M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" />
                </svg>
              </div>
              <ul class="error-messages">
                <li v-if="errors.email">{{ errors.email }}</li>
                <li v-if="errors.password">{{ errors.password }}</li>
              </ul>
            </div>

            <button class="button primary" type="submit" :disabled="isSubmitting">
              <div v-if="isSubmitting" class="button-spinner"></div>
              <span v-else>Sign In</span>
            </button>
          </form>
        </div>
      </div>

      <!-- Footer -->
      <p class="footer-text">
        Don't have an account? 
        <router-link to="/register" class="support-link">Sign up here</router-link>
      </p>
    </div>
  </div>
</template>

<script>
import axios from "axios";

export default {
  data() {
    return {
      email: "",
      password: "",
      errors: {},
      isSubmitting: false,
    };
  },
  methods: {
    async login() {
      if (this.isSubmitting) return;
      this.isSubmitting = true;

      try {
        this.errors = {};
        const response = await axios.post(
          "/auth",
          { email: this.email, password: this.password },
          { headers: { "Content-Type": "application/json" } }
        );

        localStorage.setItem("jwt_token", response.data.token);
        this.$router.push("/dashboard");
      } catch (error) {
        if (error.response && error.response.status === 401) {
          this.errors.email = "Invalid email or password.";
        } else {
          console.error("Login failed:", error);
        }
      } finally {
        this.isSubmitting = false;
      }
    },
  },
};
</script>

<style scoped>
.login-container {
  min-height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 1rem;
  background: linear-gradient(135deg, #f0f4ff 0%, #eef1ff 100%);
}

.login-card-wrapper {
  width: 100%;
  max-width: 440px;
}

.login-card {
  background: white;
  border-radius: 1rem;
  overflow: hidden;
  box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
}

.card-header {
  background: linear-gradient(to right, #3b82f6, #4f46e5);
  padding: 2rem 1.5rem;
  text-align: center;
  color: white;
}

.header-icon {
  width: 4rem;
  height: 4rem;
  margin: 0 auto 1rem;
  background: rgba(255, 255, 255, 0.1);
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  backdrop-filter: blur(4px);
}

.card-header h2 {
  font-size: 1.5rem;
  font-weight: 700;
  margin: 0 0 0.5rem;
}

.card-header p {
  color: rgba(255, 255, 255, 0.9);
  margin: 0;
}

.card-content {
  padding: 2rem 1.5rem;
  box-sizing: border-box;
}

.card-content form {
  width: 100%;
}

.form-group {
  margin-bottom: 1rem;
}

.form-group input {
  width: 100%;
  padding: 0.875rem 1rem;
  border: 1px solid #e5e7eb;
  border-radius: 0.5rem;
  font-size: 1rem;
  transition: all 0.2s;
  background: #f9fafb;
  box-sizing: border-box;
}

.form-group input:focus {
  outline: none;
  border-color: #3b82f6;
  background: white;
  box-shadow: 0 0 0 4px rgba(59, 130, 246, 0.1);
}

.form-group input:disabled {
  background: #f3f4f6;
  cursor: not-allowed;
}

.error-container {
  background: #fee2e2;
  border-radius: 0.5rem;
  padding: 1rem;
  margin-bottom: 1rem;
  display: flex;
  align-items: flex-start;
  gap: 0.75rem;
}

.error-icon {
  width: 1.25rem;
  height: 1.25rem;
  color: #dc2626;
  flex-shrink: 0;
  margin-top: 0.125rem;
}

.error-messages {
  list-style: none;
  padding: 0;
  margin: 0;
  color: #dc2626;
  font-size: 0.875rem;
}

.error-messages li {
  margin-bottom: 0.25rem;
}

.error-messages li:last-child {
  margin-bottom: 0;
}

.button {
  display: flex;
  width: 100%;
  padding: 0.875rem 1rem;
  border-radius: 0.5rem;
  font-weight: 500;
  justify-content: center;
  align-items: center;
  transition: all 0.2s;
  cursor: pointer;
  border: none;
  font-size: 1rem;
}

.button.primary {
  background: linear-gradient(to right, #3b82f6, #4f46e5);
  color: white;
  box-shadow: 0 4px 12px rgba(59, 130, 246, 0.25);
}

.button.primary:hover:not(:disabled) {
  background: linear-gradient(to right, #2563eb, #4338ca);
}

.button.primary:disabled {
  opacity: 0.7;
  cursor: not-allowed;
}

.button-spinner {
  width: 1.25rem;
  height: 1.25rem;
  border: 2px solid white;
  border-top-color: transparent;
  border-radius: 50%;
  animation: spin 0.8s linear infinite;
}

@keyframes spin {
  to {
    transform: rotate(360deg);
  }
}

.footer-text {
  text-align: center;
  color: #4b5563;
  font-size: 0.875rem;
  margin-top: 1rem;
}

.support-link {
  color: #3b82f6;
  text-decoration: none;
  font-weight: 500;
}

.support-link:hover {
  color: #2563eb;
}

.icon {
  width: 1.5rem;
  height: 1.5rem;
}

/* Responsive adjustments */
@media (max-width: 640px) {
  .login-container {
    padding: 1rem;
  }
  
  .card-header {
    padding: 1.5rem 1rem;
  }
  
  .card-content {
    padding: 1.5rem 1rem;
  }
}
</style>